[![license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/fraunhoferportugal/tsfel/blob/master/LICENSE.txt)
![py368 status](https://img.shields.io/badge/python3.6.8-supported-green.svg)
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fraunhoferportugal/tsfel/blob/master/notebooks/TSFEL_HAR_Example.ipynb)

# Time Series Feature Extraction Library
## Intuitive time series feature extraction
This repository hosts the *TSFEL - Time Series Feature Extraction Library* python package. *TSFEL* assists researchers on exploratory feature extraction tasks on time series without requiring significant programming effort.

Users can interact with *TSFEL* using two methods:
##### Online
It does not requires installation as it relies on Google Colabs and a user interface provided by Google Sheets

##### Offline
Advanced users can take full potential of *TSFEL* by installing as a *python* package
```python
pip install https://github.com/fraunhoferportugal/tsfel/archive/v0.0.2.zip
```

## Includes a comprehensive number of features
*TSFEL* is optimized for time series and automatically extracts over 50 different features on the statistical, temporal and spectral domains.

## Functionalities
* **Intuitive, fast deployment and reproducible**: interactive UI for feature selection and customization
* **Computational complexity evaluation**: estimate the computational effort before extracting features
* **Comprehensive documentation**: each feature extraction method has a detailed explanation
* **Unit tested**: we provide unit tests for each feature
* **Easily extended**: adding new features is easy and we encourage you to contribute with your custom features

## Acknowledgements
We would like to acknowledge the financial support obtained from North Portugal Regional Operational Programme (NORTE 2020), Portugal 2020 and the European Regional Development Fund (ERDF) from European Union through the project Symbiotic technology for societal efficiency gains: Deus ex Machina (DEM), NORTE-01-0145-FEDER-000026.
